mds-lang-extension
==================
This module extends the list of available languages in Tryton. 
There are no new translations. You can use the new languages 
in the language selection of the parties.

Install
=======

pip install mds-lang-extension

Requires
========
- Tryton 4.6

Changes
=======

*0.1.3 - 07/27/2017*

- added Kurdish, Chechen, Tamil (Sri Lanka)

*0.1.2 - 07/13/2017*

- added persian for AF + TJ
- added countries for arabic language

*0.1.1 - 07/12/2017*

- added german translations

*0.1.0 - 07/12/2017*

- first public version
